Documentation
¶
Index ¶
- func DayStart(t time.Time) time.Time
- func NextWeekday(day time.Weekday, t time.Time) time.Time
- func WeekEnd(day time.Weekday, t time.Time) time.Time
- func WeekStart(day time.Weekday, t time.Time) time.Time
- func YearEnd(t time.Time) time.Time
- func YearQuarter(t time.Time) int
- func YearStart(t time.Time) time.Time
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NextWeekday ¶
Returns midnight of the next desired weekday
If the desired weekday is the current day then the current day will be returned
func WeekStart ¶
Returns midnight of the start of the week for a given day
If the desired weekday is the current day then the current day will be returned
func YearEnd ¶
Equivalent to 1 nanosecond before midnight of January 1st for the following year of the provided date time taking into account the location
func YearQuarter ¶
Quarter of the provided year in the range of 1-4
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.